@@ -45,6 +45,7 @@ class WebDriver(webdriver.Remote):
         # add new method to the `find_by_*` pantheon
         By.IOS_UIAUTOMATION = MobileBy.IOS_UIAUTOMATION
         By.IOS_PREDICATE = MobileBy.IOS_PREDICATE
+        By.IOS_CLASS_CHAIN = MobileBy.IOS_CLASS_CHAIN
         By.ANDROID_UIAUTOMATOR = MobileBy.ANDROID_UIAUTOMATOR
         By.ACCESSIBILITY_ID = MobileBy.ACCESSIBILITY_ID
 
@@ -122,6 +123,28 @@ class WebDriver(webdriver.Remote):
         """
         return self.find_elements(by=By.IOS_PREDICATE, value=predicate_string)
 
+    def find_element_by_ios_class_chain(self, class_chain_string):
+        """Find an element by ios class chain string.
+
+        :Args:
+         - class_chain_string - The class chain string
+
+        :Usage:
+            driver.find_element_by_ios_class_chain('XCUIElementTypeWindow/XCUIElementTypeButton[3]')
+        """
+        return self.find_element(by=By.IOS_CLASS_CHAIN, value=class_chain_string)
+
+    def find_elements_by_ios_class_chain(self, class_chain_string):
+        """Finds elements by ios class chain string.
+
+        :Args:
+         - class_chain_string - The class chain string
+
+        :Usage:
+            driver.find_elements_by_ios_class_chain('XCUIElementTypeWindow[2]/XCUIElementTypeAny[-2]')
+        """
+        return self.find_elements(by=By.IOS_CLASS_CHAIN, value=class_chain_string)
+
     def find_element_by_android_uiautomator(self, uia_string):
         """Finds element by uiautomator in Android.
 
@@ -424,10 +447,16 @@ class WebDriver(webdriver.Remote):
 
     @property
     def current_activity(self):
-        """Retrieves the current activity on the device.
+        """Retrieves the current activity running on the device.
         """
         return self.execute(Command.GET_CURRENT_ACTIVITY)['value']
 
+    @property
+    def current_package(self):
+        """Retrieves the current package running on the device.
+        """
+        return self.execute(Command.GET_CURRENT_PACKAGE)['value']
+
     def wait_activity(self, activity, timeout, interval=1):
         """Wait for an activity: block until target activity presents
         or time out.
@@ -785,11 +814,15 @@ class WebDriver(webdriver.Remote):
 
     # extend find element by name for backward compatibility testwa
     def find_element_by_name(self, name):
-        body = {'using': By.ACCESSIBILITY_ID, 'value': name, 'mode': 'byName'}
+        # body = {'using': By.ACCESSIBILITY_ID, 'value': name, 'mode': 'byName'}
+        xpath = "//*[@content-desc='{0}']|//*[@text='{0}']".format(name)
+        body = {'using': By.XPATH, 'value': xpath, 'mode': 'byName'}
         return self.execute(SeleniumCommand.FIND_ELEMENT, body)['value']
 
     def find_elements_by_name(self, name):
-        body = {'using': By.ACCESSIBILITY_ID, 'value': name, 'mode': 'byName'}
+        # body = {'using': By.ACCESSIBILITY_ID, 'value': name, 'mode': 'byName'}
+        xpath = "//*[@content-desc='{0}']|//*[@text='{0}']".format(name)
+        body = {'using': By.XPATH, 'value': xpath, 'mode': 'byName'}
         return self.execute(SeleniumCommand.FIND_ELEMENTS, body)['value']
 
     # add checking points testwa
@@ -873,6 +906,8 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/device/long_press_keycode')
         self.command_executor._commands[Command.GET_CURRENT_ACTIVITY] = \
             ('GET', '/session/$sessionId/appium/device/current_activity')
+        self.command_executor._commands[Command.GET_CURRENT_PACKAGE] = \
+            ('GET', '/session/$sessionId/appium/device/current_package')
         self.command_executor._commands[Command.SET_IMMEDIATE_VALUE] = \
             ('POST', '/session/$sessionId/appium/element/$id/value')
         self.command_executor._commands[Command.PULL_FILE] = \
